@@ -53,7 +53,6 @@ struct define<> {
 	}
 };
 
-
 template <typename A0>
 struct define<A0> {
 	typedef define<A0> value_type;
@@ -799,12 +798,11 @@ struct define<A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11, A12, A13, A14, A
 };
 
 
-define<> make_define()
+inline define<> make_define()
 {
 	return define<>();
 }
 
-
 template <typename A0>
 define<A0> make_define(A0& a0)
 {
@@ -902,7 +900,6 @@ define<A0, A1, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11, A12, A13, A14, A15> mak
 }
 
 
-
 }  // namespace type
 }  // namespace msgpack
 
